You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2014/04/29 21:25:24 UTC

svn commit: r1591062 [8/15] - in /openoffice/trunk/main: registry/inc/registry/ registry/tools/ rhino/ ridljar/com/sun/star/lib/util/ ridljar/com/sun/star/uno/ rsc/inc/ rsc/source/parser/ rsc/source/rscpp/ sal/inc/osl/ sal/inc/rtl/ sal/inc/sal/ sal/inc...

Modified: openoffice/trunk/main/svx/inc/svx/svdobj.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/inc/svx/svdobj.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/inc/svx/svdobj.hxx (original)
+++ openoffice/trunk/main/svx/inc/svx/svdobj.hxx Tue Apr 29 19:25:03 2014
@@ -658,7 +658,7 @@ public:
 
 	// #111111#
 	// To make clearer that this method may trigger RecalcBoundRect and thus may be
-	// expensive and somtimes problematic (inside a bigger object change You will get
+	// expensive and sometimes problematic (inside a bigger object change You will get
 	// non-useful BoundRects sometimes) i rename that method from GetBoundRect() to
 	// GetCurrentBoundRect().
 	virtual const Rectangle& GetCurrentBoundRect() const;

Modified: openoffice/trunk/main/svx/inc/svx/svdouno.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/inc/svx/svdouno.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/inc/svx/svdouno.hxx (original)
+++ openoffice/trunk/main/svx/inc/svx/svdouno.hxx Tue Apr 29 19:25:03 2014
@@ -145,7 +145,7 @@ protected:
 private:
     /** retrieves the typed ViewContact for the object
         @param _out_rpContact
-            Upon successfull return, ->_out_rpContact contains the ViewContact.
+            Upon successful return, ->_out_rpContact contains the ViewContact.
         @return
             <TRUE/> if and only if the contact was successfully retrieved. In this case,
             ->_out_rpContact contains a pointer to this contact.

Modified: openoffice/trunk/main/svx/inc/svx/svdpage.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/inc/svx/svdpage.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/inc/svx/svdpage.hxx (original)
+++ openoffice/trunk/main/svx/inc/svx/svdpage.hxx Tue Apr 29 19:25:03 2014
@@ -236,7 +236,7 @@ public:
         @return
             This method returns <TRUE/> when the navigation positions stored
             in SdrObjects are up to date.
-            It returns <FALSE/> when teh navigation positions are not valid,
+            It returns <FALSE/> when the navigation positions are not valid,
             for example because no explicit navigation order has been
             defined, i.e. HasObjectNavigationOrder() would return <FALSE/>.
     */

Modified: openoffice/trunk/main/svx/inc/svx/svdpntv.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/inc/svx/svdpntv.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/inc/svx/svdpntv.hxx (original)
+++ openoffice/trunk/main/svx/inc/svx/svdpntv.hxx Tue Apr 29 19:25:03 2014
@@ -389,7 +389,7 @@ public:
 
 	// #i72889# used from CompleteRedraw() implementation internally, added to be able to do a complete redraw in single steps
 	//
-	// BeginCompleteRedraw returns (or even creates) a SdrPaintWindow whcih shall then be used as
+	// BeginCompleteRedraw returns (or even creates) a SdrPaintWindow which shall then be used as
 	// target for paints. Since paints may be buffered, use it's GetTargetOutputDevice() method which will
 	// return the buffer in case of bufered.
 	// DoCompleteRedraw draws the DrawingLayer hierarchy then.

Modified: openoffice/trunk/main/svx/inc/svx/xtable.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/inc/svx/xtable.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/inc/svx/xtable.hxx (original)
+++ openoffice/trunk/main/svx/inc/svx/xtable.hxx Tue Apr 29 19:25:03 2014
@@ -211,7 +211,7 @@ typedef ::boost::shared_ptr< XBitmapList
 
 //////////////////////////////////////////////////////////////////////////////
 // XPropertyListFactory to limit XListSharedPtr creation and thus XPropertyList creation
-// to this factory, so noone can instantiate a non-shared instace of XPropertyList
+// to this factory, so no one can instantiate a non-shared instace of XPropertyList
 // or it's derivates
 
 class SVX_DLLPUBLIC XPropertyListFactory

Modified: openoffice/trunk/main/svx/source/accessibility/ChildrenManagerImpl.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/accessibility/ChildrenManagerImpl.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/accessibility/ChildrenManagerImpl.cxx (original)
+++ openoffice/trunk/main/svx/source/accessibility/ChildrenManagerImpl.cxx Tue Apr 29 19:25:03 2014
@@ -306,7 +306,7 @@ void ChildrenManagerImpl::CreateListOfVi
 
     Rectangle aVisibleArea = maShapeTreeInfo.GetViewForwarder()->GetVisibleArea();
 
-    // Add the visible shapes for wich the accessible objects already exist.
+    // Add the visible shapes for which the accessible objects already exist.
     AccessibleShapeList::iterator I,aEnd = maAccessibleShapes.end();
     for (I=maAccessibleShapes.begin(); I != aEnd; ++I)
     {
@@ -875,7 +875,7 @@ sal_Bool ChildrenManagerImpl::ReplaceChi
                 uno::Any(),
                 uno::makeAny (I->mxAccessibleShape));
 
-            // Replace with replacement and send an event about existance
+            // Replace with replacement and send an event about existence
             // of the new child.
             I->mxAccessibleShape = pNewChild;
             mrContext.CommitChange (

Modified: openoffice/trunk/main/svx/source/accessibility/ChildrenManagerImpl.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/accessibility/ChildrenManagerImpl.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/accessibility/ChildrenManagerImpl.hxx (original)
+++ openoffice/trunk/main/svx/source/accessibility/ChildrenManagerImpl.hxx Tue Apr 29 19:25:03 2014
@@ -89,7 +89,7 @@ public:
     /** Create a children manager, which manages the children of the given
         parent.  The parent is used for creating accessible objects.  The
         list of shapes for which to create those objects is not derived from
-        the parent and has to be provided seperately by calling one of the
+        the parent and has to be provided separately by calling one of the
         update methods.
         @param rxParent
             The parent of the accessible objects which will be created
@@ -184,7 +184,7 @@ public:
 
     /** Update the child manager.  Take care of a modified set of children
         and modified visible area.  This method can optimize the update
-        process with respect seperate updates of a modified children list
+        process with respect separate updates of a modified children list
         and visible area.
         @param bCreateNewObjectsOnDemand
             If </true> then accessible objects associated with the visible
@@ -274,10 +274,10 @@ public:
         (or more) aspect of the view forwarder.
         @param aChangeType
             A change type of <const>VISIBLE_AREA</const> leads to a call to
-            the <member>Update</memeber> which creates accessible objects of
+            the <member>Update</member> which creates accessible objects of
             new shapes immediately.  Other change types are passed to the
             visible accessible children without calling
-            <member>Update</memeber>.
+            <member>Update</member>.
         @param pViewForwarder
             The modified view forwarder.  Use this one from now on.
     */
@@ -521,7 +521,7 @@ public:
     
     /** This flag is set during the visibility calculation and indicates
         that at one time in this process an event is sent that informs the
-        listners of the creation of a new accessible object.  This flags is
+        listeners of the creation of a new accessible object.  This flags is
         not reset afterwards.  Don't use it unless you know exactly what you
         are doing.
     */

Modified: openoffice/trunk/main/svx/source/accessibility/DGColorNameLookUp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/accessibility/DGColorNameLookUp.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/accessibility/DGColorNameLookUp.cxx (original)
+++ openoffice/trunk/main/svx/source/accessibility/DGColorNameLookUp.cxx Tue Apr 29 19:25:03 2014
@@ -109,7 +109,7 @@ DGColorNameLookUp::DGColorNameLookUp (vo
     }
     catch (uno::RuntimeException e)
     {
-        // When an excpetion occured then whe have an empty name sequence
+        // When an excpetion occurred then whe have an empty name sequence
         // and the loop below is not entered.
     }
 

Modified: openoffice/trunk/main/svx/source/accessibility/svxpixelctlaccessiblecontext.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/accessibility/svxpixelctlaccessiblecontext.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/accessibility/svxpixelctlaccessiblecontext.cxx (original)
+++ openoffice/trunk/main/svx/source/accessibility/svxpixelctlaccessiblecontext.cxx Tue Apr 29 19:25:03 2014
@@ -1256,7 +1256,7 @@ Rectangle SvxPixelCtlAccessibleChild::Ge
 
 Rectangle SvxPixelCtlAccessibleChild::GetBoundingBox( void ) throw( RuntimeException )
 {
-	// no guard neccessary, because no one changes mpBoundingBox after creating it
+	// no guard necessary, because no one changes mpBoundingBox after creating it
 	ThrowExceptionIfNotAlive();
 
 	return *mpBoundingBox;

Modified: openoffice/trunk/main/svx/source/accessibility/svxrectctaccessiblecontext.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/accessibility/svxrectctaccessiblecontext.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/accessibility/svxrectctaccessiblecontext.cxx (original)
+++ openoffice/trunk/main/svx/source/accessibility/svxrectctaccessiblecontext.cxx Tue Apr 29 19:25:03 2014
@@ -602,7 +602,7 @@ void SAL_CALL SvxRectCtlAccessibleContex
 	DBG_ASSERT( pData,
 		"SvxRectCtlAccessibleContext::selectAccessibleChild(): this is an impossible state! Or at least should be..." );
 
-	// this does all wich is needed, including the change of the child's state!
+	// this does all which is needed, including the change of the child's state!
 	mpRepr->SetActualRP( pData->ePoint );
 }
 
@@ -1299,7 +1299,7 @@ Rectangle SvxRectCtlChildAccessibleConte
 
 Rectangle SvxRectCtlChildAccessibleContext::GetBoundingBox( void ) throw( RuntimeException )
 {
-	// no guard neccessary, because no one changes mpBoundingBox after creating it
+	// no guard necessary, because no one changes mpBoundingBox after creating it
 	ThrowExceptionIfNotAlive();
 
 	return *mpBoundingBox;

Modified: openoffice/trunk/main/svx/source/dialog/dlgctrl.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/dialog/dlgctrl.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/dialog/dlgctrl.cxx (original)
+++ openoffice/trunk/main/svx/source/dialog/dlgctrl.cxx Tue Apr 29 19:25:03 2014
@@ -1098,7 +1098,7 @@ Rectangle SvxPixelCtl::implCalFocusRect(
 	return Rectangle(nLeft,nTop,nRight,nBottom);
 }
 
-//Solution:Keyboard fucntion
+//Solution:Keyboard function
 void SvxPixelCtl::KeyInput( const KeyEvent& rKEvt )
 {
 	KeyCode aKeyCode = rKEvt.GetKeyCode();

Modified: openoffice/trunk/main/svx/source/dialog/docrecovery.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/dialog/docrecovery.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/dialog/docrecovery.cxx (original)
+++ openoffice/trunk/main/svx/source/dialog/docrecovery.cxx Tue Apr 29 19:25:03 2014
@@ -448,7 +448,7 @@ ERecoveryState RecoveryCore::mapDocState
     ERecoveryState eRecState = E_NOT_RECOVERED_YET;
 
     /* Attention:
-        Some of the following states can occure at the
+        Some of the following states can occur at the
         same time. So we have to check for the "worst case" first!
 
         DAMAGED -> INCOMPLETE -> HANDLED
@@ -596,7 +596,7 @@ void RecoveryCore::impl_startListening()
 //===============================================
 void RecoveryCore::impl_stopListening()
 {
-    // Ignore it, if this instance doesnt listen currently
+    // Ignore it, if this instance doesn't listen currently
     if (!m_xRealCore.is())
         return;
 
@@ -757,7 +757,7 @@ SaveDialog::SaveDialog(Window*       pPa
     FreeResource();
 
     // Prepare the office for the following crash save step.
-    // E.g. hide all open widows so the user cant influence our
+    // E.g. hide all open widows so the user can't influence our
     // operation .-)
     m_pCore->doEmergencySavePrepare();
 
@@ -1323,7 +1323,7 @@ short RecoveryDialog::execute()
                      Application::Yield();
 
                  // TODO: show BrokenRecoveryDialog again, ift he user
-                 // doesnt accepted it last time.
+                 // doesn't accepted it last time.
 
                  if (m_bUserDecideNext)
                      return DLG_RET_OK;

Modified: openoffice/trunk/main/svx/source/dialog/pfiledlg.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/dialog/pfiledlg.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/dialog/pfiledlg.cxx (original)
+++ openoffice/trunk/main/svx/source/dialog/pfiledlg.cxx Tue Apr 29 19:25:03 2014
@@ -204,7 +204,7 @@ SvxPluginFileDlg::~SvxPluginFileDlg()
 /*************************************************************************
 |*
 |* Plugins available for the the MIME-Typ in nKind
-|* (whith nKind = SID_INSERT_SOUND for MIME-Type audio
+|* (with nKind = SID_INSERT_SOUND for MIME-Type audio
 |*                SID_INSERT_VIDEO for MIME-Type video
 |*
 \************************************************************************/

Modified: openoffice/trunk/main/svx/source/engine3d/helperminimaldepth3d.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/engine3d/helperminimaldepth3d.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/engine3d/helperminimaldepth3d.cxx (original)
+++ openoffice/trunk/main/svx/source/engine3d/helperminimaldepth3d.cxx Tue Apr 29 19:25:03 2014
@@ -194,7 +194,7 @@ double getMinimalDepthInViewCoordinates(
                 aViewInfo3D.getViewTime(),
                 aViewInfo3D.getExtendedInformationSequence());
 
-            // create extractor helper, proccess geometry and get return value
+            // create extractor helper, process geometry and get return value
             drawinglayer::processor3d::MinimalDephInViewExtractor aExtractor(aNewViewInformation3D);
             aExtractor.process(aPrimitives);
             fRetval = aExtractor.getMinimalDepth();

Modified: openoffice/trunk/main/svx/source/fmcomp/fmgridcl.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/fmcomp/fmgridcl.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/fmcomp/fmgridif.cxx (original)
+++ openoffice/trunk/main/svx/source/fmcomp/fmgridif.cxx Tue Apr 29 19:25:03 2014
@@ -1509,7 +1509,7 @@ void FmXGridPeer::propertyChange(const P
 			sal_Int32 nWidth = 0;
 			if (evt.NewValue.getValueType().getTypeClass() == TypeClass_VOID)
 				nWidth = pGrid->GetDefaultColumnWidth(pGrid->GetColumnTitle(nId));
-				// GetDefaultColumnWidth already considerd the zoom factor
+				// GetDefaultColumnWidth already considered the zoom factor
 			else
 			{
 				sal_Int32 nTest = 0;
@@ -2554,7 +2554,7 @@ Reference< ::com::sun::star::frame::XDis
 	{
 		m_bInterceptingDispatch = sal_True;
 			// safety against recursion : as we are master of the first chain element and slave of the last one we would
-			// have an infinite loop without this if no dispatcher can fullfill the rewuest)
+			// have an infinite loop without this if no dispatcher can fulfill the rewuest)
 		xResult = m_xFirstDispatchInterceptor->queryDispatch(aURL, aTargetFrameName, nSearchFlags);
 		m_bInterceptingDispatch = sal_False;
 	}

Modified: openoffice/trunk/main/svx/source/fmcomp/gridcell.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/fmcomp/gridcell.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/fmcomp/gridcell.cxx (original)
+++ openoffice/trunk/main/svx/source/fmcomp/gridcell.cxx Tue Apr 29 19:25:03 2014
@@ -1606,7 +1606,7 @@ void DbFormattedField::updateFromModel( 
     ::rtl::OUString sText;
     Any aValue = _rxModel->getPropertyValue( FM_PROP_EFFECTIVE_VALUE );
     if ( aValue >>= sText )
-    {   // our effective value is transfered as string
+    {   // our effective value is transferred as string
         pFormattedWindow->SetTextFormatted( sText );
         pFormattedWindow->SetSelection( Selection( SELECTION_MAX, SELECTION_MIN ) );
     }
@@ -1845,7 +1845,7 @@ String DbPatternField::GetFormatText(con
     }
     else
         OSL_ENSURE( rpFormatter->getColumn() == _rxField, "DbPatternField::GetFormatText: my value formatter is working for another field ...!" );
-        // re-creating the value formatter here everytime would be quite expensive ...
+        // re-creating the value formatter here every time would be quite expensive ...
 
     String sText;
     if ( rpFormatter.get() )

Modified: openoffice/trunk/main/svx/source/fmcomp/gridctrl.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/fmcomp/gridctrl.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/fmcomp/gridctrl.cxx (original)
+++ openoffice/trunk/main/svx/source/fmcomp/gridctrl.cxx Tue Apr 29 19:25:03 2014
@@ -367,7 +367,7 @@ void DbGridControl::NavigationBar::Posit
 {
 	if (m_bPositioning)
 		return;
-	// the MoveToPosition may cause a LoseFocus which would lead to a second MoveToPosition, so protect agains this
+	// the MoveToPosition may cause a LoseFocus which would lead to a second MoveToPosition, so protect against this
 	// recursion
 	// 68167 - 13.08.99 - FS
 	m_bPositioning = sal_True;
@@ -1317,7 +1317,7 @@ sal_uInt16 DbGridControl::SetOptions(sal
 	}
 	else
 		nNewMode &= ~BROWSER_HIDECURSOR;
-		// should not be neccessary if EnablePermanentCursor is used to change the cursor behaviour, but to be sure ...
+		// should not be necessary if EnablePermanentCursor is used to change the cursor behaviour, but to be sure ...
 
 	if (nNewMode != m_nMode)
 	{
@@ -1643,7 +1643,7 @@ void DbGridControl::setDataSource(const 
 	// there are rows so go to the selected current column
 	if (nRecordCount)
 		GoToRowColumnId(0, GetColumnId(nCurPos));
-	// else stop the editing if neccessary
+	// else stop the editing if necessary
 	else if (IsEditing())
 		DeactivateCell();
 
@@ -1809,7 +1809,7 @@ void DbGridControl::ColumnMoved(sal_uInt
 	//				+---+---+---+---+---+---+
 	//
 	// Now, all is consistent again.
-	// (except of the hidden column : The cycling of the cols occured on the model, not on the view. maybe
+	// (except of the hidden column : The cycling of the cols occurred on the model, not on the view. maybe
 	// the user expected the latter but there really is no good argument against our method ;) ...)
 	//
 	// And no, this large explanation isn't just because I wanted to play a board game or something like
@@ -2293,7 +2293,7 @@ void DbGridControl::AdjustDataSource(sal
 	if (bFull)
 		m_xCurrentRow = NULL;
 	// if we are on the same row only repaint
-	// but this is only possible for rows which are not inserted, in that case the comparision result
+	// but this is only possible for rows which are not inserted, in that case the comparison result
 	// may not be correct
 	else
         if  (   m_xCurrentRow.Is()
@@ -3384,7 +3384,7 @@ sal_Bool DbGridControl::SaveRow()
 			// if we are appending we still sit on the insert row
 			// we don't move just clear the flags not to move on the current row
 			m_xCurrentRow->SetState(m_pDataCursor, sal_False);
-			TRACE_RANGE_MESSAGE1("explicit SetState after a successfull update, new state : %s", ROWSTATUS(m_xCurrentRow));
+			TRACE_RANGE_MESSAGE1("explicit SetState after a successful update, new state : %s", ROWSTATUS(m_xCurrentRow));
 			m_xCurrentRow->SetNew(sal_False);
 
 			// adjust the seekcursor if it is on the same position as the datacursor

Modified: openoffice/trunk/main/svx/source/form/dbtoolsclient.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/form/dbtoolsclient.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/form/dbtoolsclient.cxx (original)
+++ openoffice/trunk/main/svx/source/form/dbtoolsclient.cxx Tue Apr 29 19:25:03 2014
@@ -76,7 +76,7 @@ namespace svxform
 			    if ( pDBTFactory )
 			    {
 				    m_xDataAccessFactory = pDBTFactory;
-				    // by definition, the factory was aquired once
+				    // by definition, the factory was acquired once
 				    m_xDataAccessFactory->release();
 			    }
 		    }

Modified: openoffice/trunk/main/svx/source/form/filtnav.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/form/filtnav.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/form/filtnav.cxx (original)
+++ openoffice/trunk/main/svx/source/form/filtnav.cxx Tue Apr 29 19:25:03 2014
@@ -1367,7 +1367,7 @@ sal_Int8 FmFilterNavigator::AcceptDrop( 
 				bNeedTrigger = sal_True;
 			}
 			else
-			{	// is it an entry whith children, and not yet expanded?
+			{	// is it an entry with children, and not yet expanded?
 				SvLBoxEntry* pDropppedOn = GetEntry(aDropPos);
 				if (pDropppedOn && (GetChildCount(pDropppedOn) > 0) && !IsExpanded(pDropppedOn))
 				{

Modified: openoffice/trunk/main/svx/source/form/fmPropBrw.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/form/fmPropBrw.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/form/fmPropBrw.cxx (original)
+++ openoffice/trunk/main/svx/source/form/fmPropBrw.cxx Tue Apr 29 19:25:03 2014
@@ -229,7 +229,7 @@ FmPropBrw::FmPropBrw( const Reference< X
 		{
             // create an intermediate window, which is to be the container window of the frame
             // Do *not* use |this| as container window for the frame, this would result in undefined
-            // responsiblity for this window (as soon as we initialize a frame with a window, the frame
+            // responsibility for this window (as soon as we initialize a frame with a window, the frame
             // is responsible for it's life time, but |this| is controlled by the belonging SfxChildWindow)
             // #i34249# - 2004-09-27 - fs@openoffice.org
             Window* pContainerWindow = new Window( this );
@@ -244,7 +244,7 @@ FmPropBrw::FmPropBrw( const Reference< X
                         xSupp ( _pBindings->GetDispatcher()->GetFrame()->GetFrame().GetFrameInterface(), ::com::sun::star::uno::UNO_QUERY );
 //                if ( xSupp.is() )
 //                    xSupp->getFrames()->append( m_xMeAsFrame );
-                // Don't append frame to frame hierachy to prevent UI_DEACTIVATE messages
+                // Don't append frame to frame hierarchy to prevent UI_DEACTIVATE messages
                 // #i31834# - 2004-07-27 - cd@openoffice.org
             }
 		}
@@ -712,7 +712,7 @@ void FmPropBrw::StateChanged(sal_uInt16 
 	}
 	catch (Exception&)
 	{
-		DBG_ERROR("FmPropBrw::StateChanged: Exception occured!");
+		DBG_ERROR("FmPropBrw::StateChanged: Exception occurred!");
 	}
     m_bInStateChange = false;
 }

Modified: openoffice/trunk/main/svx/source/form/fmobj.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/form/fmobj.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/form/fmobj.cxx (original)
+++ openoffice/trunk/main/svx/source/form/fmobj.cxx Tue Apr 29 19:25:03 2014
@@ -294,7 +294,7 @@ void FmFormObj::SetPage(SdrPage* _pNewPa
 		Reference< XFormComponent >  xMeAsFormComp(GetUnoControlModel(), UNO_QUERY);
 		if (xMeAsFormComp.is())
 		{
-			// check if I have another parent (and remove me, if neccessary)
+			// check if I have another parent (and remove me, if necessary)
 			Reference< XIndexContainer >  xOldParent(xMeAsFormComp->getParent(), UNO_QUERY);
 			if (xOldParent.is())
 			{
@@ -671,7 +671,7 @@ FASTBOOL FmFormObj::EndCreate( SdrDragSt
                 Reference< XIndexContainer > xFormToInsertInto;
 
                 if ( !xParentForm.is() )
-                {   // model is not yet part of a form component hierachy
+                {   // model is not yet part of a form component hierarchy
                     xParentForm.set( rPage.GetImpl().findPlaceInFormComponentHierarchy( xContent ), UNO_SET_THROW );
                     xFormToInsertInto.set( xParentForm, UNO_QUERY_THROW );
 		        }

Modified: openoffice/trunk/main/svx/source/form/fmshimp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/form/fmshimp.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/form/fmshimp.cxx (original)
+++ openoffice/trunk/main/svx/source/form/fmshimp.cxx Tue Apr 29 19:25:03 2014
@@ -1736,7 +1736,7 @@ void FmXFormShell::SetY2KState(sal_uInt1
 				}
 				catch(Exception&)
 				{
-					DBG_ERROR("FmXFormShell::SetY2KState: Exception occured!");
+					DBG_ERROR("FmXFormShell::SetY2KState: Exception occurred!");
 				}
 
 			}
@@ -1777,7 +1777,7 @@ void FmXFormShell::SetY2KState(sal_uInt1
 				}
 				catch(Exception&)
 				{
-					DBG_ERROR("FmXFormShell::SetY2KState: Exception occured!");
+					DBG_ERROR("FmXFormShell::SetY2KState: Exception occurred!");
 				}
 
 			}
@@ -3029,7 +3029,7 @@ void FmXFormShell::startFiltering()
 	Reference< XControlContainer> xContainer;
 	if (getActiveController() == m_xExternalViewController)
 	{
-		DBG_ASSERT(m_xExtViewTriggerController.is(), "FmXFormShell::startFiltering : inconsistent : active external controller, but noone triggered this !");
+		DBG_ASSERT(m_xExtViewTriggerController.is(), "FmXFormShell::startFiltering : inconsistent : active external controller, but no one triggered this !");
 		xContainer = m_xExtViewTriggerController->getContainer();
 	}
 	else
@@ -3106,7 +3106,7 @@ void FmXFormShell::stopFiltering(sal_Boo
 	Reference< XControlContainer> xContainer;
 	if (getActiveController() == m_xExternalViewController)
 	{
-		DBG_ASSERT(m_xExtViewTriggerController.is(), "FmXFormShell::stopFiltering : inconsistent : active external controller, but noone triggered this !");
+		DBG_ASSERT(m_xExtViewTriggerController.is(), "FmXFormShell::stopFiltering : inconsistent : active external controller, but no one triggered this !");
 		xContainer = m_xExtViewTriggerController->getContainer();
 	}
 	else
@@ -3171,7 +3171,7 @@ void FmXFormShell::stopFiltering(sal_Boo
 				}
 				catch(Exception&)
 				{
-					DBG_ERROR("FmXFormShell::stopFiltering: Exception occured!");
+					DBG_ERROR("FmXFormShell::stopFiltering: Exception occurred!");
 				}
 
 				if (!isRowSetAlive(xFormSet))
@@ -3242,7 +3242,7 @@ void FmXFormShell::clearFilter()
 	Reference< XControlContainer> xContainer;
 	if (getActiveController() == m_xExternalViewController)
 	{
-		DBG_ASSERT(m_xExtViewTriggerController.is(), "FmXFormShell::clearFilter : inconsistent : active external controller, but noone triggered this !");
+		DBG_ASSERT(m_xExtViewTriggerController.is(), "FmXFormShell::clearFilter : inconsistent : active external controller, but no one triggered this !");
 		xContainer = m_xExtViewTriggerController->getContainer();
 	}
 	else

Modified: openoffice/trunk/main/svx/source/form/fmsrcimp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/form/fmsrcimp.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/form/fmsrcimp.cxx (original)
+++ openoffice/trunk/main/svx/source/form/fmsrcimp.cxx Tue Apr 29 19:25:03 2014
@@ -908,7 +908,7 @@ void FmSearchEngine::Init(const ::rtl::O
     }
     catch(Exception&)
     {
-        DBG_ERROR("Exception occured!");
+        DBG_ERROR("Exception occurred!");
     }
 
 }

Modified: openoffice/trunk/main/svx/source/form/fmundo.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/form/fmundo.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/form/fmundo.cxx (original)
+++ openoffice/trunk/main/svx/source/form/fmundo.cxx Tue Apr 29 19:25:03 2014
@@ -433,7 +433,7 @@ void FmXUndoEnvironment::Inserted(FmForm
 			    if ( lcl_searchElement( xForms, xObjectParent ) )
                 {
                     // the form which was the parent of the object when it was removed is still
-                    // part of the form component hierachy of the current page
+                    // part of the form component hierarchy of the current page
 				    xNewParent = xObjectParent;
                     xForm.set( xNewParent, UNO_QUERY_THROW );
                     nPos = ::std::min( pObj->GetOriginalIndex(), xNewParent->getCount() );

Modified: openoffice/trunk/main/svx/source/form/fmvwimp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/form/fmvwimp.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/form/fmvwimp.cxx (original)
+++ openoffice/trunk/main/svx/source/form/fmvwimp.cxx Tue Apr 29 19:25:03 2014
@@ -1496,7 +1496,7 @@ bool FmXFormView::createControlLabelPair
         )
         return false;
 
-    // insert the control model(s) into the form component hierachy
+    // insert the control model(s) into the form component hierarchy
     if ( _rpLabel )
         lcl_insertIntoFormComponentHierarchy_throw( *m_pView, *_rpLabel, _rxDataSource, _rDataSourceName, _rCommand, _nCommandType );
     lcl_insertIntoFormComponentHierarchy_throw( *m_pView, *_rpControl, _rxDataSource, _rDataSourceName, _rCommand, _nCommandType );

Modified: openoffice/trunk/main/svx/source/form/formcontroller.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/form/formcontroller.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/form/formcontroller.cxx (original)
+++ openoffice/trunk/main/svx/source/form/formcontroller.cxx Tue Apr 29 19:25:03 2014
@@ -1062,7 +1062,7 @@ void SAL_CALL FormController::removeDisj
     FmFilterRows::iterator pos = m_aFilterRows.begin() + _Term;
     m_aFilterRows.erase( pos );
 
-    // adjust m_nCurrentFilterPosition if the removed row preceeded it
+    // adjust m_nCurrentFilterPosition if the removed row preceded it
     if ( _Term < m_nCurrentFilterPosition )
         --m_nCurrentFilterPosition;
 
@@ -3138,7 +3138,7 @@ void FormController::setFilter(::std::ve
 		Sequence < PropertyValue> aLevel;
 		Sequence< Sequence < PropertyValue > > aFilterRows = m_xComposer->getStructuredFilter();
 
-		// ok, we recieve the list of filters as sequence of fieldnames, value
+		// ok, we receive the list of filters as sequence of fieldnames, value
 		// now we have to transform the fieldname into UI names, that could be a label of the field or
 		// a aliasname or the fieldname itself
 

Modified: openoffice/trunk/main/svx/source/form/formdispatchinterceptor.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/form/formdispatchinterceptor.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/form/formdispatchinterceptor.cxx (original)
+++ openoffice/trunk/main/svx/source/form/formdispatchinterceptor.cxx Tue Apr 29 19:25:03 2014
@@ -81,7 +81,7 @@ namespace svxform
 	    {
 		    _rxToIntercept->registerDispatchProviderInterceptor((XDispatchProviderInterceptor*)this);
 		    // this should make us the top-level dispatch-provider for the component, via a call to our
-		    // setDispatchProvider we should have got an fallback for requests we (i.e. our master) cannot fullfill
+		    // setDispatchProvider we should have got an fallback for requests we (i.e. our master) cannot fulfill
 		    Reference< XComponent> xInterceptedComponent(_rxToIntercept, UNO_QUERY);
 		    if (xInterceptedComponent.is())
 		    {

Modified: openoffice/trunk/main/svx/source/form/navigatortree.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/form/navigatortree.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/form/navigatortree.cxx (original)
+++ openoffice/trunk/main/svx/source/form/navigatortree.cxx Tue Apr 29 19:25:03 2014
@@ -1871,7 +1871,7 @@ namespace svxform
                     m_arrCurrentSelection.Remove( i - 1, 1 );
                 }
                 // In case there is no shape for the current entry, we keep the entry in m_arrCurrentSelection,
-                // since then we can definately remove it.
+                // since then we can definitely remove it.
                 // #103597#
 			}
 		}

Modified: openoffice/trunk/main/svx/source/gallery2/galtheme.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/gallery2/galtheme.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/gallery2/galtheme.cxx (original)
+++ openoffice/trunk/main/svx/source/gallery2/galtheme.cxx Tue Apr 29 19:25:03 2014
@@ -435,7 +435,7 @@ sal_Bool GalleryTheme::InsertObject( con
         {
     		GalleryObject aNewEntry;
 
-            // update title of new object if neccessary
+            // update title of new object if necessary
             if( !rObj.GetTitle().Len() )
             {
                 SgaObject* pOldObj = ImplReadSgaObject( pFoundEntry );

Modified: openoffice/trunk/main/svx/source/inc/docrecovery.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/inc/docrecovery.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/inc/fmshimp.hxx (original)
+++ openoffice/trunk/main/svx/source/inc/fmshimp.hxx Tue Apr 29 19:25:03 2014
@@ -477,7 +477,7 @@ public:
 		// if the form belongs to the controller (extern) displaying a grid, the according internal form will
 		// be displayed, _xForm else
 
-    // check if the current control of the active controler has the focus
+    // check if the current control of the active controller has the focus
     bool    HasControlFocus() const;
 
 private:

Modified: openoffice/trunk/main/svx/source/inc/fmtextcontrolshell.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/inc/fmtextcontrolshell.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/inc/fmtextcontrolshell.hxx (original)
+++ openoffice/trunk/main/svx/source/inc/fmtextcontrolshell.hxx Tue Apr 29 19:25:03 2014
@@ -93,7 +93,7 @@ namespace svx
         // without this define, m_xActiveControl remembers the *last* active control, even
         // if it, in the meantime, already lost the focus
         bool                                                                        m_bActiveControl;
-            // so we need an additional boolean flag telling whether the active cotrol
+            // so we need an additional boolean flag telling whether the active control
             // is really focused
 #endif
         bool                                                                        m_bActiveControlIsReadOnly;

Modified: openoffice/trunk/main/svx/source/sdr/contact/displayinfo.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/sdr/contact/displayinfo.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/sdr/contact/displayinfo.cxx (original)
+++ openoffice/trunk/main/svx/source/sdr/contact/displayinfo.cxx Tue Apr 29 19:25:03 2014
@@ -53,7 +53,7 @@ namespace sdr
 		{
 		}
 
-		// Access to LayerInfos (which layers to proccess)
+		// Access to LayerInfos (which layers to process)
 		void DisplayInfo::SetProcessLayers(const SetOfByte& rSet)
 		{
 			maProcessLayers = rSet;

Modified: openoffice/trunk/main/svx/source/sdr/contact/viewobjectcontactofpageobj.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/sdr/contact/viewobjectcontactofpageobj.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/sdr/contact/viewobjectcontactofpageobj.cxx (original)
+++ openoffice/trunk/main/svx/source/sdr/contact/viewobjectcontactofpageobj.cxx Tue Apr 29 19:25:03 2014
@@ -266,7 +266,7 @@ namespace sdr
 					// set recursion flag
 					bInCreatePrimitive2D = true;
 
-					// init extractor, guarantee existance, set page there
+					// init extractor, guarantee existence, set page there
 					mpExtractor->SetStartPage(pPage);
 
                     // #i105548# also need to copy the VOCRedirector for sub-content creation

Modified: openoffice/trunk/main/svx/source/sdr/event/eventhandler.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/sdr/event/eventhandler.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/sdr/event/eventhandler.cxx (original)
+++ openoffice/trunk/main/svx/source/sdr/event/eventhandler.cxx Tue Apr 29 19:25:03 2014
@@ -25,7 +25,7 @@
 #include "precompiled_svx.hxx"
 #include <svx/sdr/event/eventhandler.hxx>
 
-// for SOLARIS compiler include of algorithm part of _STL is necesary to
+// for SOLARIS compiler include of algorithm part of _STL is necessary to
 // get access to basic algos like ::std::find
 #include <algorithm>
 #include <tools/debug.hxx>

Modified: openoffice/trunk/main/svx/source/sdr/overlay/overlayobjectlist.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/sdr/overlay/overlayobjectlist.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/sdr/overlay/overlayobjectlist.cxx (original)
+++ openoffice/trunk/main/svx/source/sdr/overlay/overlayobjectlist.cxx Tue Apr 29 19:25:03 2014
@@ -29,7 +29,7 @@
 #include <vcl/outdev.hxx>
 #include <basegfx/matrix/b2dhommatrix.hxx>
 
-// for SOLARIS compiler include of algorithm part of _STL is necesary to
+// for SOLARIS compiler include of algorithm part of _STL is necessary to
 // get access to basic algos like ::std::find
 #include <algorithm>
 

Modified: openoffice/trunk/main/svx/source/sdr/primitive2d/sdrole2primitive2d.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/sdr/primitive2d/sdrole2primitive2d.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/sdr/primitive2d/sdrole2primitive2d.cxx (original)
+++ openoffice/trunk/main/svx/source/sdr/primitive2d/sdrole2primitive2d.cxx Tue Apr 29 19:25:03 2014
@@ -78,7 +78,7 @@ namespace drawinglayer
 			// to take care of getSdrLFSTAttribute() later, the same as in SdrGrafPrimitive2D::create2DDecomposition
 			// should happen. For the moment we only need the OLE itself
 			// Added complete primitive preparation using getSdrLFSTAttribute() now. To not do stuff which is not needed now, it
-			// may be supressed by using a static bool. The paint version only supported text.
+			// may be suppressed by using a static bool. The paint version only supported text.
 			static bool bBehaveCompatibleToPaintVersion(false);
 			Primitive2DSequence  aRetval;
 
@@ -153,7 +153,7 @@ namespace drawinglayer
 			// add graphic content
 			appendPrimitive2DSequenceToPrimitive2DSequence(aRetval, getOLEContent());
 
-			// add text, no need to supress to stay compatible since text was
+			// add text, no need to suppress to stay compatible since text was
 			// always supported by the old paints, too
 			if(!getSdrLFSTAttribute().getText().isDefault())
 			{

Modified: openoffice/trunk/main/svx/source/sidebar/paragraph/ParaPropertyPanel.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/sidebar/paragraph/ParaPropertyPanel.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/sidebar/paragraph/ParaPropertyPanel.hxx (original)
+++ openoffice/trunk/main/svx/source/sidebar/paragraph/ParaPropertyPanel.hxx Tue Apr 29 19:25:03 2014
@@ -178,7 +178,7 @@ private:
 	SfxMapUnit                      m_eULSpaceUnit;
 	/****************************************************************
 	**
-	** Controll Items
+	** Control Items
 	**
 	*****************************************************************/
 

Modified: openoffice/trunk/main/svx/source/svdraw/svdedtv2.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/svdraw/svdedtv2.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/svdraw/svdedtv2.cxx (original)
+++ openoffice/trunk/main/svx/source/svdraw/svdedtv2.cxx Tue Apr 29 19:25:03 2014
@@ -1063,7 +1063,7 @@ void SdrEditView::MergeMarkedObjects(Sdr
 				pInsPV = pM->GetPageView();
 				pInsOL = pObj->GetObjList();
 
-				// #i76891# use single iter from SJ here whcih works on SdrObjects and takes
+				// #i76891# use single iter from SJ here which works on SdrObjects and takes
 				// groups into account by itself
 				SdrObjListIter aIter(*pObj, IM_DEEPWITHGROUPS);
 
@@ -1235,7 +1235,7 @@ void SdrEditView::CombineMarkedObjects(s
 	// #114310#
 	// This is used for Combine and Connect. In no case it is necessary to force
 	// the content to curve, but it is also not good to force to polygons. Thus,
-	// curve is the less information loosing one. Remember: This place is not
+	// curve is the less information losing one. Remember: This place is not
 	// used for merge.
 	// LineToArea is never necessary, both commands are able to take over the
 	// set line style and to display it correctly. Thus, i will use a

Modified: openoffice/trunk/main/svx/source/svdraw/svdedxv.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/svdraw/svdedxv.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/svdraw/svdedxv.cxx (original)
+++ openoffice/trunk/main/svx/source/svdraw/svdedxv.cxx Tue Apr 29 19:25:03 2014
@@ -251,7 +251,7 @@ void SdrObjEditView::ModelHasChanged()
 			// which makes the Handles visible. Changes at TakeTextRect()
 			// seem to have resulted in a case where no refresh is executed.
 			// Before that, a refresh must have been always executed
-			// (else this error would have happend earlier), thus i
+			// (else this error would have happened earlier), thus i
 			// even think here a refresh should be done always.
 			// Since follow-up problems cannot even be guessed I only
 			// add this one more case to the if below.

Modified: openoffice/trunk/main/svx/source/svdraw/svdhdl.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/svdraw/svdhdl.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/svdraw/svdhdl.cxx (original)
+++ openoffice/trunk/main/svx/source/svdraw/svdhdl.cxx Tue Apr 29 19:25:03 2014
@@ -265,7 +265,7 @@ const BitmapEx& SdrHdlBitmapSet::GetBitm
 		}
 	}
 
-	// cannot happen since all pathes return something; return Rect_7x7 as default (see switch)
+	// cannot happen since all paths return something; return Rect_7x7 as default (see switch)
     return maRealMarkers[0];
 }
 
@@ -2606,7 +2606,7 @@ void SdrCropViewHdl::CreateB2dIAObject()
         aCropped.getMinY());
     aCroppedTransform = maObjectTransform * aCroppedTransform;
 
-    // prepare graphic primitive (tranformed)
+    // prepare graphic primitive (transformed)
     const drawinglayer::primitive2d::Primitive2DReference aGraphic(
         new drawinglayer::primitive2d::GraphicPrimitive2D(
             aCroppedTransform,

Modified: openoffice/trunk/main/svx/source/svdraw/svdobj.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/svdraw/svdobj.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/svdraw/svdobj.cxx (original)
+++ openoffice/trunk/main/svx/source/svdraw/svdobj.cxx Tue Apr 29 19:25:03 2014
@@ -899,7 +899,7 @@ void SdrObject::SetNavigationPosition (c
 
 // #111111#
 // To make clearer that this method may trigger RecalcBoundRect and thus may be
-// expensive and somtimes problematic (inside a bigger object change You will get
+// expensive and sometimes problematic (inside a bigger object change You will get
 // non-useful BoundRects sometimes) i rename that method from GetBoundRect() to
 // GetCurrentBoundRect().
 const Rectangle& SdrObject::GetCurrentBoundRect() const

Modified: openoffice/trunk/main/svx/source/svdraw/svdoedge.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/svdraw/svdoedge.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/svdraw/svdoedge.cxx (original)
+++ openoffice/trunk/main/svx/source/svdraw/svdoedge.cxx Tue Apr 29 19:25:03 2014
@@ -2505,9 +2505,9 @@ void SdrEdgeObj::SetTailPoint( sal_Bool 
 }
 
 /** this method is used by the api to set a glue point for a connection
-	nId == -1 :		The best default point is automaticly choosen
-	0 <= nId <= 3 : One of the default points is choosen
-	nId >= 4 :		A user defined glue point is choosen
+	nId == -1 :		The best default point is automatically chosen
+	0 <= nId <= 3 : One of the default points is chosen
+	nId >= 4 :		A user defined glue point is chosen
 */
 void SdrEdgeObj::setGluePointIndex( sal_Bool bTail, sal_Int32 nIndex /* = -1 */ )
 {

Modified: openoffice/trunk/main/svx/source/svdraw/svdograf.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/svdraw/svdograf.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/svdraw/svdograf.cxx (original)
+++ openoffice/trunk/main/svx/source/svdraw/svdograf.cxx Tue Apr 29 19:25:03 2014
@@ -150,7 +150,7 @@ const Graphic ImpLoadLinkedGraphic( cons
         // handing it over means that any GraphicFormat that internallv needs a path as base
         // to interpret included links may fail.
         // Alternatively the path may be set at the result after this call when it is known
-        // that it is a SVG graphic, but only because noone yet tried to interpret it.
+        // that it is a SVG graphic, but only because no one yet tried to interpret it.
         pGF->ImportGraphic( aGraphic, aFileName, *pInStrm, nFilter, NULL, 0, &aFilterData );
 	}
 	return aGraphic;

Modified: openoffice/trunk/main/svx/source/svdraw/svdoole2.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/svdraw/svdoole2.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/svdraw/svdoole2.cxx (original)
+++ openoffice/trunk/main/svx/source/svdraw/svdoole2.cxx Tue Apr 29 19:25:03 2014
@@ -317,7 +317,7 @@ void SAL_CALL SdrLightEmbeddedClient_Imp
 		if ( !mpObj )
 			throw embed::ObjectSaveVetoException();
 
-		// the common persistance is supported by objects and links
+		// the common persistence is supported by objects and links
 		xPersist = uno::Reference< embed::XCommonEmbedPersist >( mpObj->GetObjRef(), uno::UNO_QUERY_THROW );
 		xModifiable = uno::Reference< util::XModifiable >( mpObj->GetParentXModel(), uno::UNO_QUERY );
 	}
@@ -1291,7 +1291,7 @@ void SdrOle2Obj::Disconnect_Impl()
 				// TODO/LATER: here we must assume that the destruction of the model is enough to make clear that we will not
 				// remove the object from the container, even if the DrawingObject itself is not destroyed (unfortunately this
 				// There is no real need to do the following removing of the object from the container
-				// in case the model has correct persistance, but in case of problems such a removing
+				// in case the model has correct persistence, but in case of problems such a removing
 				// would make the behaviour of the office more stable
 
 				comphelper::EmbeddedObjectContainer* pContainer = xObjRef.GetContainer();

Modified: openoffice/trunk/main/svx/source/svdraw/svdotxtr.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/svdraw/svdotxtr.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/svdraw/svdotxtr.cxx (original)
+++ openoffice/trunk/main/svx/source/svdraw/svdotxtr.cxx Tue Apr 29 19:25:03 2014
@@ -184,7 +184,7 @@ void SdrTextObj::NbcResize(const Point& 
 		// #100663# aRect is NOT initialized for lines (polgon objects with two
 		// exceptionally handled points). Thus, after this call the text rotaion is
 		// gone. This error must be present since day one of this old drawing layer.
-		// It's astonishing that noone discovered it earlier.
+		// It's astonishing that no one discovered it earlier.
 		// Polygon aPol(Rect2Poly(aRect,aGeo));
 		// Polygon aPol(Rect2Poly(GetSnapRect(), aGeo));
 		

Modified: openoffice/trunk/main/svx/source/svdraw/svdundo.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/svdraw/svdundo.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/svdraw/svdundo.cxx (original)
+++ openoffice/trunk/main/svx/source/svdraw/svdundo.cxx Tue Apr 29 19:25:03 2014
@@ -446,7 +446,7 @@ void SdrUndoAttrObj::Undo()
 		// #105122# Since ClearItem sets back everything to normal
 		// it also sets fit-to-size text to non-fit-to-size text and
 		// switches on autogrowheight (the default). That may lead to
-		// loosing the geometry size info for the object when it is
+		// losing the geometry size info for the object when it is
 		// re-layouted from AdjustTextFrameWidthAndHeight(). This makes
 		// rescuing the size of the object necessary.
 		const Rectangle aSnapRect = pObj->GetSnapRect();

Modified: openoffice/trunk/main/svx/source/svdraw/svdxcgv.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/svdraw/svdxcgv.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/svdraw/svdxcgv.cxx (original)
+++ openoffice/trunk/main/svx/source/svdraw/svdxcgv.cxx Tue Apr 29 19:25:03 2014
@@ -579,7 +579,7 @@ BitmapEx SdrExchangeView::GetMarkedObjBi
 
                     if(pSdrGrafObj)
                     {
-                        // #122753# To ensure existance of graphic content, force swap in
+                        // #122753# To ensure existence of graphic content, force swap in
                         pSdrGrafObj->ForceSwapIn();
                     }
 
@@ -662,7 +662,7 @@ GDIMetaFile SdrExchangeView::GetMarkedOb
             aMtf.SetPrefMapMode( aMap );
 
 			// removed PrefSize extension. It is principially wrong to set a reduced size at
-			// the created MetaFile. The mentioned errors occurr at output time since the integer
+			// the created MetaFile. The mentioned errors occur at output time since the integer
 			// MapModes from VCL lead to errors. It is now corrected in the VCLRenderer for
 			// primitives (and may later be done in breaking up a MetaFile to primitives)
 			aMtf.SetPrefSize(aBoundSize);

Modified: openoffice/trunk/main/svx/source/table/celltypes.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/table/celltypes.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/table/celltypes.hxx (original)
+++ openoffice/trunk/main/svx/source/table/celltypes.hxx Tue Apr 29 19:25:03 2014
@@ -80,7 +80,7 @@ public:
 	}
 
 	/* iterates in the configured direction and returns true if rValue
-	   now contains a valid positon in the range of this iterator */
+	   now contains a valid position in the range of this iterator */
 	bool next( T& rValue )
 	{
 		if( maIter == maEnd )

Modified: openoffice/trunk/main/svx/source/table/tablelayouter.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/table/tablelayouter.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/table/tablelayouter.hxx (original)
+++ openoffice/trunk/main/svx/source/table/tablelayouter.hxx Tue Apr 29 19:25:03 2014
@@ -72,7 +72,7 @@ public:
 	
 		if bFitWidth or bFitHeight is set, the layouter tries to scale
 		the rows and/or columns to the given area. The result my be bigger
-		to fullfill constrains.
+		to fulfill constrains.
 
 		if bFitWidth or bFitHeight is set, the model is changed.
 	*/

Modified: openoffice/trunk/main/svx/source/tbxctrls/SvxColorValueSet.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/tbxctrls/SvxColorValueSet.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/tbxctrls/SvxColorValueSet.cxx (original)
+++ openoffice/trunk/main/svx/source/tbxctrls/SvxColorValueSet.cxx Tue Apr 29 19:25:03 2014
@@ -118,7 +118,7 @@ Size SvxColorValueSet::layoutToGivenHeig
     const Size aItemSize(getEntryEdgeLength(), getEntryEdgeLength());
     const WinBits aWinBits(GetStyle() & ~WB_VSCROLL);
 
-    // get size whith all fields disabled
+    // get size with all fields disabled
     const WinBits aWinBitsNoScrollNoFields(GetStyle() & ~(WB_VSCROLL|WB_NAMEFIELD|WB_NONEFIELD));
     SetStyle(aWinBitsNoScrollNoFields);
     const Size aSizeNoScrollNoFields(CalcWindowSizePixel(aItemSize, getColumnCount()));

Modified: openoffice/trunk/main/svx/source/unodialogs/textconversiondlgs/chinese_translationdialog.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/unodialogs/textconversiondlgs/chinese_translationdialog.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/unodialogs/textconversiondlgs/chinese_translationdialog.cxx (original)
+++ openoffice/trunk/main/svx/source/unodialogs/textconversiondlgs/chinese_translationdialog.cxx Tue Apr 29 19:25:03 2014
@@ -85,7 +85,7 @@ ChineseTranslationDialog::ChineseTransla
 	if( aAny >>= bValue )
 	    m_aCB_Use_Variants.Check( bValue );
 
-    // #117820# (search for other occurences!)
+    // #117820# (search for other occurrences!)
     // disable and hide that checkbox until it is decided if it is needed or not.
     // If it is to be removed later the respective code needs to be removed as
     // well, otherwise we just have to remove the next lines again.
@@ -127,7 +127,7 @@ void ChineseTranslationDialog::getSettin
 
 void ChineseTranslationDialog::impl_UpdateVariantsCheckBox()
 {
-// #117820# (search for other occurences!)
+// #117820# (search for other occurrences!)
 //    m_aCB_Use_Variants.Enable( m_aRB_To_Traditional.IsChecked() );
 }
 
@@ -139,7 +139,7 @@ IMPL_LINK( ChineseTranslationDialog, Dir
 
 IMPL_LINK( ChineseTranslationDialog, CommonTermsHdl, void*, EMPTYARG )
 {
-// #117820# (search for other occurences!)
+// #117820# (search for other occurrences!)
 //    if( m_aCB_Translate_Commonterms.IsChecked() && m_aRB_To_Traditional.IsChecked() )
 //        m_aCB_Use_Variants.Check( true );
     return 0;

Modified: openoffice/trunk/main/svx/source/unodraw/unopage.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/unodraw/unopage.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/unodraw/unopage.cxx (original)
+++ openoffice/trunk/main/svx/source/unodraw/unopage.cxx Tue Apr 29 19:25:03 2014
@@ -222,7 +222,7 @@ void SvxDrawPage::dispose()
 			::com::sun::star::document::EventObject aEvt;
 			aEvt.Source = xSource;
 			// inform all listeners to release this object
-			// The listener container are automaticly cleared
+			// The listener container are automatically cleared
 			mrBHelper.aLC.disposeAndClear( aEvt );
 			// notify subclasses to do their dispose
 			disposing();

Modified: openoffice/trunk/main/svx/source/unodraw/unoshcol.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/unodraw/unoshcol.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/unodraw/unoshcol.cxx (original)
+++ openoffice/trunk/main/svx/source/unodraw/unoshcol.cxx Tue Apr 29 19:25:03 2014
@@ -129,7 +129,7 @@ void SvxShapeCollection::dispose()
 			document::EventObject aEvt;
 			aEvt.Source = xSource;
 			// inform all listeners to release this object
-			// The listener container are automaticly cleared
+			// The listener container are automatically cleared
 			mrBHelper.aLC.disposeAndClear( aEvt );
 			// notify subclasses to do their dispose
 			disposing();

Modified: openoffice/trunk/main/svx/source/xml/xmleohlp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/xml/xmleohlp.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/xml/xmleohlp.cxx (original)
+++ openoffice/trunk/main/svx/source/xml/xmleohlp.cxx Tue Apr 29 19:25:03 2014
@@ -421,7 +421,7 @@ sal_Bool SvXMLEmbeddedObjectHelper::Impl
 
     if( xDocStor != xCntnrStor || pTemp || bDuplicate )
 	{
-        // TODO/LATER: make this alltogether a method in the EmbeddedObjectContainer
+        // TODO/LATER: make this altogether a method in the EmbeddedObjectContainer
 
 		// create a unique name for the duplicate object
         if( bDuplicate )

Modified: openoffice/trunk/main/sw/inc/IInterface.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/inc/IInterface.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/inc/IInterface.hxx (original)
+++ openoffice/trunk/main/sw/inc/IInterface.hxx Tue Apr 29 19:25:03 2014
@@ -32,7 +32,7 @@
  { 
  public:
     
-    /** Aquire a reference to an instance. A caller shall release
+    /** Acquire a reference to an instance. A caller shall release
 	    the instance by calling 'release' when it is no longer needed.
         'acquire' and 'release' calls need to be balanced.
         
@@ -42,7 +42,7 @@
     virtual sal_Int32 acquire() = 0;
     
     /** Releases a reference to an instance. A caller has to call
-        'release' when a before aquired reference to an instance
+        'release' when a before acquired reference to an instance
         is no longer needed. 'acquire' and 'release' calls need to 
         be balanced. 
 	

Modified: openoffice/trunk/main/sw/inc/SwNumberTree.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/inc/SwNumberTree.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/inc/SwNumberTree.hxx (original)
+++ openoffice/trunk/main/sw/inc/SwNumberTree.hxx Tue Apr 29 19:25:03 2014
@@ -457,7 +457,7 @@ protected:
     mutable SwNumberTree::tSwNumTreeNumber mnNumber;
 
     // --> OD 2008-11-26 #158694#
-    // boolean indicating, that a node of a not counted parent node is continueing
+    // boolean indicating, that a node of a not counted parent node is continuing
     // the numbering of parent's previous node sub tree.
     // Example:
     //   1. kshdkjfs
@@ -508,7 +508,7 @@ protected:
     /**
        Invalidates a child.
 
-       Calls SetLastValid for the preceeding sibling of the child and
+       Calls SetLastValid for the preceding sibling of the child and
        notifies all invalid children.
 
        @param pChild      the child to invalidate
@@ -544,7 +544,7 @@ protected:
        @param aItLastValid    iterator pointing to the new last valid child
        @param bValidating     - true    always set the last valid node to
                                         aItLastValid
-                              - false   only set if aItLastValid is preceeding
+                              - false   only set if aItLastValid is preceding
                                         the current last valid node
      */
     void SetLastValid(tSwNumberTreeChildren::const_iterator aItLastValid,

Modified: openoffice/trunk/main/sw/inc/accmap.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/inc/accmap.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/inc/accmap.hxx (original)
+++ openoffice/trunk/main/sw/inc/accmap.hxx Tue Apr 29 19:25:03 2014
@@ -128,7 +128,7 @@ class SwAccessibleMap : public ::accessi
 
 	//mpSelectedFrmMap contains the old selected objects.
 	SwAccessibleContextMap_Impl *mpSeletedFrmMap;
-	//IvalidateShapeInParaSelection() method is reponsible for the updating the selected states of the objects.
+	//IvalidateShapeInParaSelection() method is responsible for the updating the selected states of the objects.
 	void InvalidateShapeInParaSelection();
 
     void _InvalidateRelationSet( const SwFrm* pFrm, sal_Bool bFrom );

Modified: openoffice/trunk/main/sw/inc/ndnotxt.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/inc/ndnotxt.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/inc/ndnotxt.hxx (original)
+++ openoffice/trunk/main/sw/inc/ndnotxt.hxx Tue Apr 29 19:25:03 2014
@@ -41,7 +41,7 @@ class SW_DLLPUBLIC SwNoTxtNode : public 
 	PolyPolygon *pContour;		// Polygon fuer Konturumlauf
     sal_Bool bAutomaticContour : 1; // automatic contour polygon, not manipulated
 	sal_Bool bContourMapModeValid : 1; // contour map mode is not the graphics's
-								   // prefered map mode, but either
+								   // preferred map mode, but either
    								   // MM100 or or pixel
 	sal_Bool bPixelContour : 1;		// contour map mode is invalid and pixel.
 

Modified: openoffice/trunk/main/sw/inc/pagepreviewlayout.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/inc/pagepreviewlayout.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/inc/pagepreviewlayout.hxx (original)
+++ openoffice/trunk/main/sw/inc/pagepreviewlayout.hxx Tue Apr 29 19:25:03 2014
@@ -481,7 +481,7 @@ public:
         @param _orNewStartPos
         output parameter - new start position in document preview
 
-        @return boolean - indicating, that move was sucessful.
+        @return boolean - indicating, that move was successful.
     */
     bool CalcStartValuesForSelectedPageMove( const sal_Int16  _nHoriMove,
                                              const sal_Int16  _nVertMove,

Modified: openoffice/trunk/main/sw/source/core/access/acccell.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/source/core/access/acccell.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/source/core/access/acccell.cxx (original)
+++ openoffice/trunk/main/sw/source/core/access/acccell.cxx Tue Apr 29 19:25:03 2014
@@ -143,7 +143,7 @@ sal_Bool SwAccessibleCell::_InvalidateMy
 	if( bNew )
 	{
 		// remember that object as the one that has the caret. This is
-		// neccessary to notify that object if the cursor leaves it.
+		// necessary to notify that object if the cursor leaves it.
 		::vos::ORef < SwAccessibleContext > xThis( this );
 		GetMap()->SetCursorContext( xThis );
 	}

Modified: openoffice/trunk/main/sw/source/core/access/acccell.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/source/core/access/acccell.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/source/core/access/acccell.hxx (original)
+++ openoffice/trunk/main/sw/source/core/access/acccell.hxx Tue Apr 29 19:25:03 2014
@@ -58,7 +58,7 @@ class SwAccessibleCell : public	SwAccess
 protected:
 
 	// Set states for getAccessibleStateSet.
-	// This drived class additionaly sets SELECTABLE(1) and SELECTED(+)
+	// This drived class additionally sets SELECTABLE(1) and SELECTED(+)
 	virtual void GetStates( ::utl::AccessibleStateSetHelper& rStateSet );
 
 	virtual void _InvalidateCursorPos();

Modified: openoffice/trunk/main/sw/source/core/access/accframebase.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/source/core/access/accframebase.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/source/core/access/accframebase.cxx (original)
+++ openoffice/trunk/main/sw/source/core/access/accframebase.cxx Tue Apr 29 19:25:03 2014
@@ -176,7 +176,7 @@ void SwAccessibleFrameBase::_InvalidateC
 	if( bNewSelected )
 	{
 		// remember that object as the one that has the caret. This is
-		// neccessary to notify that object if the cursor leaves it.
+		// necessary to notify that object if the cursor leaves it.
 		::vos::ORef < SwAccessibleContext > xThis( this );
 		GetMap()->SetCursorContext( xThis );
 	}

Modified: openoffice/trunk/main/sw/source/core/access/accframebase.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/source/core/access/accframebase.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/source/core/access/accframebase.hxx (original)
+++ openoffice/trunk/main/sw/source/core/access/accframebase.hxx Tue Apr 29 19:25:03 2014
@@ -43,7 +43,7 @@ class SwAccessibleFrameBase : public SwA
 protected:
 
 	// Set states for getAccessibleStateSet.
-	// This drived class additionaly sets SELECTABLE(1), SELECTED(+),
+	// This drived class additionally sets SELECTABLE(1), SELECTED(+),
 	// FOCUSABLE(1) and FOCUSED(+)
 	virtual void GetStates( ::utl::AccessibleStateSetHelper& rStateSet );
 	SwFlyFrm* getFlyFrm() const;

Modified: openoffice/trunk/main/sw/source/core/access/accmap.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/source/core/access/accmap.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/source/core/access/accmap.cxx (original)
+++ openoffice/trunk/main/sw/source/core/access/accmap.cxx Tue Apr 29 19:25:03 2014
@@ -678,7 +678,7 @@ class SwAccPreviewData
         rectangle; needed to determine the visible part of the logic page rectangle.
 
         @param _rPrevwWinSize
-        input paramter - constant reference to the preview window size in TWIP;
+        input parameter - constant reference to the preview window size in TWIP;
         needed to determine the visible part of the logic page rectangle
     */
     void AdjustLogicPgRectToVisibleArea( SwRect&         _iorLogicPgSwRect,
@@ -1061,7 +1061,7 @@ void SwAccessibleMap::AppendEvent( const
 				break;
 			case SwAccessibleEvent_Impl::DISPOSE:
 				// DISPOSE events overwrite all others. They are not stored
-				// but executed immediatly to avoid broadcasting of
+				// but executed immediately to avoid broadcasting of
 				// defunctional objects. So what needs to be done here is to
 				// remove all events for the frame in question.
 				bAppendEvent = sal_False;
@@ -2020,7 +2020,7 @@ uno::Reference< XAccessible> SwAccessibl
 						// focused state then. Sending the focus changes event
 						// after that seems to be strange. However, we cannot
 						// send a focus event fo the new context now, because
-					    // noone except us knows it. In any case, we remeber
+					    // no one except us knows it. In any case, we remember
 						// the new context as the one that has the focus
 						// currently.
 

Modified: openoffice/trunk/main/sw/source/core/access/accpage.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/source/core/access/accpage.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/source/core/access/accpage.cxx (original)
+++ openoffice/trunk/main/sw/source/core/access/accpage.cxx Tue Apr 29 19:25:03 2014
@@ -90,7 +90,7 @@ void SwAccessiblePage::_InvalidateCursor
 	if( bNewSelected )
 	{
 		// remember that object as the one that has the caret. This is
-		// neccessary to notify that object if the cursor leaves it.
+		// necessary to notify that object if the cursor leaves it.
 		::vos::ORef < SwAccessibleContext > xThis( this );
 		GetMap()->SetCursorContext( xThis );
 	}

Modified: openoffice/trunk/main/sw/source/core/access/accpage.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/source/core/access/accpage.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/source/core/access/accpage.hxx (original)
+++ openoffice/trunk/main/sw/source/core/access/accpage.hxx Tue Apr 29 19:25:03 2014
@@ -49,7 +49,7 @@ protected:
 	SwRect GetBounds( /* const SwFrm *pFrm =0 */ );
 
 	// Set states for getAccessibleStateSet.
-	// This drived class additionaly sets
+	// This drived class additionally sets
 	// FOCUSABLE(1) and FOCUSED(+)
 	virtual void GetStates( ::utl::AccessibleStateSetHelper& rStateSet );
 

Modified: openoffice/trunk/main/sw/source/core/access/accpara.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/source/core/access/accpara.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/source/core/access/accpara.cxx (original)
+++ openoffice/trunk/main/sw/source/core/access/accpara.cxx Tue Apr 29 19:25:03 2014
@@ -503,7 +503,7 @@ void SwAccessibleParagraph::_InvalidateC
 	if( -1 != nNew )
 	{
 		// remember that object as the one that has the caret. This is
-		// neccessary to notify that object if the cursor leaves it.
+		// necessary to notify that object if the cursor leaves it.
 		::vos::ORef < SwAccessibleContext > xThis( this );
 		GetMap()->SetCursorContext( xThis );
 	}
@@ -846,7 +846,7 @@ sal_Bool SwAccessibleParagraph::GetWordB
 				rBound.endPos = nEndPos;
 			}
 		}
-		// add the " " into the word boundry
+		// add the " " into the word boundary
 		else
 		{
 			rBound = pBreakIt->xBreak->getWordBoundary(rText, nPos, aLocale, nWordType, sal_True );
@@ -1917,7 +1917,7 @@ uno::Sequence<PropertyValue> SwAccessibl
 		for( i = 0; i < nLength; i++ )
 			pIndices[i] = i;
 		sort( &pIndices[0], &pIndices[nLength], IndexCompare(pPairs) );
-		// create sorted sequences accoring to index array
+		// create sorted sequences according to index array
         uno::Sequence<PropertyValue> aNewValues( nLength );
 		PropertyValue* pNewValues = aNewValues.getArray();
 		for( i = 0; i < nLength; i++ )
@@ -3244,7 +3244,7 @@ sal_Bool SwAccessibleParagraph::setAttri
         pIndices[i] = i;
     sort( &pIndices[0], &pIndices[nLength], IndexCompare(pPairs) );
 
-    // create sorted sequences accoring to index array
+    // create sorted sequences according to index array
     uno::Sequence< ::rtl::OUString > aNames( nLength );
     ::rtl::OUString* pNames = aNames.getArray();
     uno::Sequence< uno::Any > aValues( nLength );

Modified: openoffice/trunk/main/sw/source/core/access/accpara.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/source/core/access/accpara.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/source/core/access/accpara.hxx (original)
+++ openoffice/trunk/main/sw/source/core/access/accpara.hxx Tue Apr 29 19:25:03 2014
@@ -202,7 +202,7 @@ protected:
     /// remove the current portion data
     void ClearPortionData();
 
-    /// get portion data; update if necesary
+    /// get portion data; update if necessary
     SwAccessiblePortionData& GetPortionData()
         throw( com::sun::star::uno::RuntimeException )
     {

Modified: openoffice/trunk/main/sw/source/core/bastyp/swrect.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/source/core/bastyp/swrect.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/source/core/bastyp/swrect.cxx (original)
+++ openoffice/trunk/main/sw/source/core/bastyp/swrect.cxx Tue Apr 29 19:25:03 2014
@@ -244,7 +244,7 @@ void SwRect::Justify()
 }
 
 
-// Similiar to the inline methods, but we need the function pointers
+// Similar to the inline methods, but we need the function pointers
 
 void SwRect::_Width( const long nNew ) { m_Size.setWidth(nNew); }
 void SwRect::_Height( const long nNew ) { m_Size.setHeight(nNew); }

Modified: openoffice/trunk/main/sw/source/core/crsr/crsrsh.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/source/core/crsr/crsrsh.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/source/core/crsr/crsrsh.cxx (original)
+++ openoffice/trunk/main/sw/source/core/crsr/crsrsh.cxx Tue Apr 29 19:25:03 2014
@@ -3274,7 +3274,7 @@ bool lcl_PosOk(const SwPosition & aPos)
 
 /**
    Checks if a PaM is valid. For a PaM to be valid its point must be
-   valid. Additionaly if the PaM has a mark this has to be valid, too.
+   valid. Additionally if the PaM has a mark this has to be valid, too.
 
    @param aPam the PaM to check
 */

Modified: openoffice/trunk/main/sw/source/core/crsr/findtxt.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/source/core/crsr/findtxt.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/source/core/crsr/findtxt.cxx (original)
+++ openoffice/trunk/main/sw/source/core/crsr/findtxt.cxx Tue Apr 29 19:25:03 2014
@@ -283,7 +283,7 @@ sal_uInt8 SwPaM::Find( const SearchOptio
 			nStart = rCntntIdx.GetIndex();
 
 			/* #i80135# */
-			// if there are SwPostItFields inside our current node text, we split the text into seperate pieces
+			// if there are SwPostItFields inside our current node text, we split the text into separate pieces
 			// and search for text inside the pieces as well as inside the fields
 			const SwpHints *pHts = ((SwTxtNode*)pNode)->GetpSwpHints();
 

Modified: openoffice/trunk/main/sw/source/core/crsr/trvltbl.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/source/core/crsr/trvltbl.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/source/core/crsr/trvltbl.cxx (original)
+++ openoffice/trunk/main/sw/source/core/crsr/trvltbl.cxx Tue Apr 29 19:25:03 2014
@@ -296,7 +296,7 @@ sal_Bool SwCrsrShell::SelTblBox()
     // if we're in a table, create a table cursor, and select the cell
     // that the current cursor's point resides in
 
-    // search for start node of our table box. If not found, exit realy
+    // search for start node of our table box. If not found, exit really
     const SwStartNode* pStartNode =
         pCurCrsr->GetPoint()->nNode.GetNode().FindTableBoxStartNode();
 

Modified: openoffice/trunk/main/sw/source/core/doc/docdde.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/source/core/doc/docdde.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/source/core/doc/docdde.cxx (original)
+++ openoffice/trunk/main/sw/source/core/doc/docdde.cxx Tue Apr 29 19:25:03 2014
@@ -162,7 +162,7 @@ sal_Bool lcl_FindTable( const SwFrmFmtPt
 bool SwDoc::GetData( const String& rItem, const String& rMimeType,
                      uno::Any & rValue ) const
 {
-    //search for bookmarks and sections case senstive at first. If nothing is found then try again case insensitive
+    //search for bookmarks and sections case sensitive at first. If nothing is found then try again case insensitive
     bool bCaseSensitive = true;
     while( true )
     {
@@ -201,7 +201,7 @@ bool SwDoc::GetData( const String& rItem
 bool SwDoc::SetData( const String& rItem, const String& rMimeType,
                      const uno::Any & rValue )
 {
-    //search for bookmarks and sections case senstive at first. If nothing is found then try again case insensitive
+    //search for bookmarks and sections case sensitive at first. If nothing is found then try again case insensitive
     bool bCaseSensitive = true;
     while( true )
     {
@@ -240,7 +240,7 @@ bool SwDoc::SetData( const String& rItem
 {
     SwServerObject* pObj = NULL;
 
-    //search for bookmarks and sections case senstive at first. If nothing is found then try again case insensitive
+    //search for bookmarks and sections case sensitive at first. If nothing is found then try again case insensitive
     bool bCaseSensitive = true;
     while( true )
     {
@@ -380,7 +380,7 @@ sal_Bool SwDoc::SelectServerObj( const S
 			return sal_False;
 	}
 
-    //search for bookmarks and sections case senstive at first. If nothing is found then try again case insensitive
+    //search for bookmarks and sections case sensitive at first. If nothing is found then try again case insensitive
     bool bCaseSensitive = true;
     while( true )
     {

Modified: openoffice/trunk/main/sw/source/core/doc/docnum.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/source/core/doc/docnum.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/source/core/doc/docnum.cxx (original)
+++ openoffice/trunk/main/sw/source/core/doc/docnum.cxx Tue Apr 29 19:25:03 2014
@@ -334,7 +334,7 @@ sal_Bool SwDoc::OutlineUpDown( const SwP
     }
 
     /* If moving of the outline levels is applicable, i.e. for all
-       outline levels occuring in the document there has to be a valid
+       outline levels occurring in the document there has to be a valid
        target outline level implied by aMoveArr. */
     bool bMoveApplicable = true;
 	for (n = nSttPos; n < nEndPos; n++)
@@ -467,7 +467,7 @@ sal_Bool SwDoc::MoveOutlinePara( const S
     // If the given range ends at an outlined text node we have to decide if it has to be a part of
     // the moving range or not. Normally it will be a sub outline of our chapter
     // and has to be moved, too. But if the chapter ends with a table(or a section end),
-    // the next text node will be choosen and this could be the next outline of the same level.
+    // the next text node will be chosen and this could be the next outline of the same level.
     // The criteria has to be the outline level: sub level => incorporate, same/higher level => no.
     if( GetNodes().GetOutLineNds().Seek_Entry( pEndSrch, &nTmpPos ) )
     {
@@ -492,8 +492,8 @@ sal_Bool SwDoc::MoveOutlinePara( const S
     // The following code corrects the range to handle sections (start/end nodes)
     // The range will be extended if the least node before the range is a start node
     // which ends inside the range => The complete section will be moved.
-    // The range will be shrinked if the last position is a start node.
-    // The range will be shrinked if the last node is an end node which starts before the range.
+    // The range will be shrunk if the last position is a start node.
+    // The range will be shrunk if the last node is an end node which starts before the range.
     aSttRg--;
     while( aSttRg.GetNode().IsStartNode() )
     {

Modified: openoffice/trunk/main/sw/source/core/doc/doctxm.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/source/core/doc/doctxm.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/source/core/doc/doctxm.cxx (original)
+++ openoffice/trunk/main/sw/source/core/doc/doctxm.cxx Tue Apr 29 19:25:03 2014
@@ -549,7 +549,7 @@ sal_Bool SwDoc::DeleteTOX( const SwTOXBa
 		   delete to. This is done by first searching forward from the
 		   end of the TOX' section. If no content node is found behind
 		   the TOX one is searched before it. If this is not
-		   successfull, too, insert new text node behind the end of
+		   successful, too, insert new text node behind the end of
 		   the TOX' section. The cursors from the TOX' section will be
 		   moved to the content node found or the new text node. */
 

Modified: openoffice/trunk/main/sw/source/core/doc/notxtfrm.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sw/source/core/doc/notxtfrm.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/sw/source/core/doc/notxtfrm.cxx (original)
+++ openoffice/trunk/main/sw/source/core/doc/notxtfrm.cxx Tue Apr 29 19:25:03 2014
@@ -909,7 +909,7 @@ void SwNoTxtFrm::PaintPicture( OutputDev
     {
         //#i78025# charts own borders are not completely visible
         //the above pixel correction is not correct - at least not for charts
-        //so a different pixel correction is choosen here
+        //so a different pixel correction is chosen here
         //this might be a good idea for all other OLE objects also,
         //but as I cannot oversee the consequences I fix it only for charts for now
         lcl_correctlyAlignRect( aAlignedGrfArea, rGrfArea, pOut );
--- openoffice/trunk/main/svx/source/fmcomp/fmgridcl.cxx (original)
+++ openoffice/trunk/main/svx/source/fmcomp/fmgridcl.cxx Tue Apr 29 19:25:03 2014
@@ -502,7 +502,7 @@ IMPL_LINK( FmGridHeader, OnAsyncExecuteD
 		}
 		catch(Exception&)
 		{
-			DBG_ERROR("FmGridHeader::ExecuteDrop: Exception occured!");
+			DBG_ERROR("FmGridHeader::ExecuteDrop: Exception occurred!");
 		}
 
 		sal_Int32 nPreferedType = -1;
@@ -1895,7 +1895,7 @@ Sequence< Any> FmGridControl::getSelecti
 
 		// The next problem caused by the same behaviuor (SeekCursor causes a propertyChanged) : when adjusting rows we implicitly
 		// change our selection. So a "FirstSelected(); SeekCursor(); NextSelected();" may produce unpredictable results.
 		// That's why we _first_ collect the indicies of the selected rows and _then_ their bookmarks.
 		long nIdx = FirstSelectedRow();
 		while (nIdx >= 0)
 		{
@@ -1903,7 +1903,7 @@ Sequence< Any> FmGridControl::getSelecti
 			pBookmarks[i++] <<= (sal_Int32)nIdx;
 			nIdx = NextSelectedRow();
 		}
-		DBG_ASSERT(i == nSelectedRows, "FmGridControl::DeleteSelectedRows : could not collect the row indicies !");
+		DBG_ASSERT(i == nSelectedRows, "FmGridControl::DeleteSelectedRows : could not collect the row indices !");
 
 		for (i=0; i<nSelectedRows; ++i)
 		{
@@ -2123,7 +2123,7 @@ void FmGridControl::KeyInput( const KeyE
 						}
 						catch(const Exception&)
 						{
-							OSL_ENSURE(0,"exception occured while deleting a column");
+							OSL_ENSURE(0,"exception occurred while deleting a column");
 						}
 					}
 				}
@@ -1895,7 +1895,7 @@ Sequence< Any> FmGridControl::getSelecti
 		// The next problem caused by the same behaviuor (SeekCursor causes a propertyChanged) : when adjusting rows we implicitly
 		// change our selection. So a "FirstSelected(); SeekCursor(); NextSelected();" may produce unpredictable results.
-		// That's why we _first_ collect the indicies of the selected rows and _then_ their bookmarks.
+		// That's why we _first_ collect the indices of the selected rows and _then_ their bookmarks.
 		long nIdx = FirstSelectedRow();
 		while (nIdx >= 0)

Modified: openoffice/trunk/main/svx/source/fmcomp/fmgridif.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/fmcomp/fmgridif.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/inc/docrecovery.hxx (original)
+++ openoffice/trunk/main/svx/source/inc/docrecovery.hxx Tue Apr 29 19:25:03 2014
@@ -127,9 +127,9 @@ enum EDocStates
 
     /* FINAL STATES */
 
     /// the Auto/Emergency saved document isnt useable any longer
     E_DAMAGED = 64,
     /// the Auto/Emergency saved document isnt realy up-to-date (some changes can be missing)
     E_INCOMPLETE = 128,
     /// the Auto/Emergency saved document was processed successfully
     E_SUCCEDED = 512
@@ -487,13 +487,13 @@ class SaveDialog : public IExtendedTabPa
         //---------------------------------------
         /** @short  create all child controls of this dialog.
 
-            @descr  The dialog isnt shown nor it starts any
+            @descr  The dialog isn't shown nor it starts any
                     action by itself!
 
             @param  pParent
                     can point to a parent window.
                     If its set to 0, the defmodal-dialog-parent
-                    is used automaticly.
+                    is used automatically.
 
             @param  pCore
                     provides access to the recovery core service
@@ -544,13 +544,13 @@ class SaveProgressDialog : public ModalD
         //---------------------------------------
         /** @short  create all child controls of this dialog.
 
-            @descr  The dialog isnt shown nor it starts any
+            @descr  The dialog isn't shown nor it starts any
                     action by itself!
 
             @param  pParent
                     can point to a parent window.
                     If its set to 0, the defmodal-dialog-parent
-                    is used automaticly.
+                    is used automatically.
 
             @param  pCore
                     used to start emegrency save.
@@ -127,9 +127,9 @@ enum EDocStates
     /* FINAL STATES */
 
-    /// the Auto/Emergency saved document isnt useable any longer
+    /// the Auto/Emergency saved document isn't useable any longer
     E_DAMAGED = 64,
@@ -127,9 +127,9 @@ enum EDocStates
     E_DAMAGED = 64,
-    /// the Auto/Emergency saved document isnt realy up-to-date (some changes can be missing)
+    /// the Auto/Emergency saved document isn't really up-to-date (some changes can be missing)
     E_INCOMPLETE = 128,
     /// the Auto/Emergency saved document was processed successfully

Modified: openoffice/trunk/main/svx/source/inc/fmshimp.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/inc/fmshimp.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================